@@ -165,3 +165,35 @@ def build_command_for_submission_check(
         "--route",
         "submissions/" + submission_id,
     ]
+
+
+def download_fasta(organism: str, locus: str) -> List[str]:
+    repo_root = get_repo_root()
+
+    return [
+        "curl",
+        "https://rest.pubmlst.org/db/pubmlst_"
+        + organism
+        + "_seqdef/loci/"
+        + locus
+        + "/alleles_fasta",
+        "-o",
+        repo_root + "/databases/" + organism + "/" + locus + ".fasta",
+    ]
+
+
+def build_blastdb(organism: str, locus: str) -> List[str]:
+    repo_root = get_repo_root()
+
+    return [
+        "singularity",
+        "exec",
+        repo_root + "/mlstfest.sif",
+        "makeblastdb",
+        "-in",
+        repo_root + "/databases/" + organism + "/" + locus + ".fasta",
+        "-dbtype",
+        "nucl",
+        "-out",
+        repo_root + "/databases/" + organism + "/" + locus + ".db",
+    ]
