@@ -10,8 +10,10 @@ from mlstfest.build_command import (
     build_command_for_allele_upload,
     build_command_for_adding_comment,
     build_command_for_submission_check,
+    download_fasta,
+    build_blastdb,
 )
-from mlstfest.utils import run_command, get_submission_id, download_fasta, build_blastdb
+from mlstfest.utils import run_command, get_submission_id
 from configs.loci import MARKERS
 
 
